import * as dynamodb from '@aws-cdk/aws-dynamodb';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface TableViewerProps {
    /**
     * The DynamoDB table to view.
     *
     * Note that all contents of this table will be
     * visible to the public.
     *
     * @stability stable
     */
    readonly table: dynamodb.Table;
    /**
     * The web page title.
     *
     * @default - No title
     * @stability stable
     */
    readonly title?: string;
    /**
     * Name of the column to sort by, prefix with "-" for descending order.
     *
     * @default - No sort
     * @stability stable
     */
    readonly sortBy?: string;
}
/**
 * Installs an endpoint in your stack that allows users to view the contents of a DynamoDB table through their browser.
 *
 * @stability stable
 */
export declare class TableViewer extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly endpoint: string;
    /**
     * @stability stable
     */
    constructor(parent: cdk.Construct, id: string, props: TableViewerProps);
}
